import React, { useState, useEffect } from 'react';
import { Card, List, Drawer, Button, Empty, Spin, notification } from 'antd';
import {
  modifyProduct,
  getProductList,
  delProductList,
} from '@/services/webConfig/api';
import classnames from 'classnames';
import AddForm from './components/productForm';
import EditForm from './components/editForm';
import styles from './productConfig.less';
const ProductConfig = props => {
  const [addVisible, setAddVisible] = useState(false);
  const [productList, setProductList] = useState([]);
  const [productObj, setProductObt] = useState(null);
  const [loading, setLoading] = useState(false);
  const [flag, setFlag] = useState(1);
  useEffect(() => {
    setLoading(true);
    getProductList()
      .then(res => {
        const { code, data } = res;
        if (code === 0) {
          if (!productObj && data.length > 0) {
            setProductObt(data[0]);
          }
          setProductList(data);
        }
      })
      .finally(() => {
        setLoading(false);
      });
  }, [flag]);
  // 展示新增抽屉
  const handleAdd = () => {
    setAddVisible(true);
  };
  // 删除
  const handleDel = () => {
    setLoading(true);
    delProductList({
      ids: productObj.Id,
    })
      .then(res => {
        setLoading(false);
        if (res.code === 0) {
          notification.success({
            message: '提示',
            description: '删除成功',
            duration: 3,
          });
          setProductObt('');
          setFlag(flag + 1);
        } else {
          notification.error({
            message: '提示',
            description: res.msg || '删除失败',
            duration: 10,
          });
        }
      })
      .catch(err => {
        setLoading(false);
        console.error(err);
      });
  };
  // 新增提交回调
  const addCallback = val => {
    setAddVisible(false);
    setFlag(flag + 1);
  };
  // 编辑的回调
  const editCallback = val => {
    setLoading(true);
    modifyProduct(val)
      .then(res => {
        setLoading(false);
        if (res.code === 0) {
          notification.success({
            message: '提示',
            description: '编辑成功',
            duration: 3,
          });
          setFlag(flag + 1);
        } else {
          notification.error({
            message: '提示',
            description: res.msg || '编辑失败',
            duration: 10,
          });
        }
      })
      .catch(err => {
        setLoading(false);
        console.log(err);
      });
  };
  const renderListItem = arr =>
    arr.map(item => (
      <List.Item
        key={item.Id}
        className={classnames({
          [styles.listItem]: true,
          [styles.selected]: item.Id === productObj.Id,
        })}
        onClick={() => setProductObt(item)}
      >
        {item.ProductName}
      </List.Item>
    ));
  return (
    <Spin spinning={loading} tip="loading...">
      <div className={styles.box}>
        <Card className={classnames(`${styles.leftList}`)}>
          <div className={styles.listTop}>
            产品选择：
            <Button type="primary" onClick={handleAdd}>
              新增
            </Button>
            {/* <Button type="primary" danger onClick={handleDel}>
              删除
            </Button> */}
          </div>
          {productList && productList.length > 0 ? (
            <List>{renderListItem(productList)}</List>
          ) : (
            <Empty
              image={Empty.PRESENTED_IMAGE_SIMPLE}
              description="暂无数据"
            />
          )}
        </Card>
        <Card className={styles.rightForm}>
          {productList && productList.length > 0 && productObj ? (
            <EditForm
              productObj={productObj}
              editCallback={editCallback}
              handleDel={handleDel}
            />
          ) : (
            <Empty
              style={{ marginTop: '60px' }}
              image={Empty.PRESENTED_IMAGE_SIMPLE}
              description="当前未选中产品类型"
            />
          )}
          <Drawer
            title="新增产品"
            destroyOnClose
            maskClosable={false}
            width={600}
            onClose={() => {
              setAddVisible(false);
            }}
            visible={addVisible}
          >
            <AddForm addCallback={addCallback} />
          </Drawer>
        </Card>
      </div>
    </Spin>
  );
};
export default ProductConfig;
